LpSolversCompat

Struct LpSolversCompat 

pub struct LpSolversCompat<'a> { /* private fields */ }
A validated wrapper that guarantees compatibility with lp-solvers.

Implementations

Source

impl<'a> LpSolversCompat<'a>

pub fn try_new(problem: &'a LpProblem) -> Result<Self, LpSolversCompatError>

Try to create a compatible wrapper from an LpProblem.

Errors

Returns an error if:

  • The Problem has multiple objectives
  • The Problem has no objectives
  • Any constraint uses strict inequalities (< or >)
Panics

Panics if the problem has exactly one objective but it cannot be accessed (internal error)

pub fn warnings(&self) -> &[LpSolversCompatWarning]

Returns any warnings generated during validation.

pub fn is_fully_compatible(&self) -> bool

Returns true if there are no warnings.